@@ -1,9 +1,10 @@
 from pathlib import Path
 
 from progress.bar import Bar
-from pyimporters_dummy.dummy import DummyOptions, DummyKnowledgeParser, DummyOptionsModel
 from pyimporters_plugins.base import Term
 
+from pyimporters_dummy.dummy import DummyKnowledgeParser, DummyOptionsModel
+
 
 def test_dummy():
     source = Path()
@@ -11,7 +12,7 @@ def test_dummy():
     options = DummyOptionsModel(foo="tests")
     concepts = list(parser.parse(source, options.dict(), Bar('Processing')))
     assert len(concepts) == 1
-    c0 : Term = concepts[0]
+    c0: Term = concepts[0]
     assert c0.identifier == 'tests'
     assert c0.preferredForm == 'tests'
     assert c0.properties['altForms'] == ['TESTS']
